@@ -16,7 +16,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_cloud9.type_defs import (
     DescribeEnvironmentMembershipsResultTypeDef,
@@ -35,7 +35,7 @@ __all__ = ("DescribeEnvironmentMembershipsPaginator", "ListEnvironmentsPaginator
 
 class DescribeEnvironmentMembershipsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEnvironmentMemberships documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
+    [Paginator.DescribeEnvironmentMemberships documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
     """
 
     def paginate(
@@ -44,20 +44,20 @@ class DescribeEnvironmentMembershipsPaginator(Boto3Paginator):
         environmentId: str = None,
         permissions: List[Literal["owner", "read-write", "read-only"]] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeEnvironmentMembershipsResultTypeDef, None, None]:
+    ) -> Iterator[DescribeEnvironmentMembershipsResultTypeDef]:
         """
-        [DescribeEnvironmentMemberships.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships.paginate)
+        [DescribeEnvironmentMemberships.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships.paginate)
         """
 
 
 class ListEnvironmentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
+    [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListEnvironmentsResultTypeDef, None, None]:
+    ) -> Iterator[ListEnvironmentsResultTypeDef]:
         """
-        [ListEnvironments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments.paginate)
+        [ListEnvironments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments.paginate)
         """
